==> intel-compute-runtime_23.35.27191.9.orig.tar.gz: compute-runtime-23.35.27191.9/shared/test/common/helpers/batch_buffer_helper.h <==
/*
 * Copyright (C) 2022-2023 Intel Corporation
 *
 * SPDX-License-Identifier: MIT
 *
 */

#pragma once
#include "shared/source/command_stream/submissions_aggregator.h"

using namespace NEO;

struct BatchBufferHelper {
    static BatchBuffer createDefaultBatchBuffer(GraphicsAllocation *commandBufferAllocation, LinearStream *stream, size_t usedSize, size_t chainedBatchBufferStartOffset) {
        return BatchBuffer(
            commandBufferAllocation,            // commandBufferAllocation
            0,                                  // startOffset
            chainedBatchBufferStartOffset,      // chainedBatchBufferStartOffset
            0,                                  // taskStartAddress
            nullptr,                            // chainedBatchBuffer
            false,                              // requiresCoherency
            false,                              // lowPriority
            QueueThrottle::MEDIUM,              // throttle
            QueueSliceCount::defaultSliceCount, // sliceCount
            usedSize,                           // usedSize
            stream,                             // stream
            nullptr,                            // endCmdPtr
            0,                                  // numCsrClients
            false,                              // hasStallingCmds
            false                               // hasRelaxedOrderingDependencies
        );
    }

    static BatchBuffer createDefaultBatchBuffer(GraphicsAllocation *commandBufferAllocation, LinearStream *stream, size_t usedSize) {
        return createDefaultBatchBuffer(commandBufferAllocation, stream, usedSize, 0);
    }
};

==> intel-compute-runtime_23.43.27642.40.orig.tar.gz: compute-runtime-23.43.27642.40/shared/test/common/helpers/batch_buffer_helper.h <==
/*
 * Copyright (C) 2022-2023 Intel Corporation
 *
 * SPDX-License-Identifier: MIT
 *
 */

#pragma once
#include "shared/source/command_stream/submissions_aggregator.h"

using namespace NEO;

struct BatchBufferHelper {
    static BatchBuffer createDefaultBatchBuffer(GraphicsAllocation *commandBufferAllocation, LinearStream *stream, size_t usedSize, size_t chainedBatchBufferStartOffset) {
        return BatchBuffer(
            commandBufferAllocation,            // commandBufferAllocation
            0,                                  // startOffset
            chainedBatchBufferStartOffset,      // chainedBatchBufferStartOffset
            0,                                  // taskStartAddress
            nullptr,                            // chainedBatchBuffer
            false,                              // lowPriority
            QueueThrottle::MEDIUM,              // throttle
            QueueSliceCount::defaultSliceCount, // sliceCount
            usedSize,                           // usedSize
            stream,                             // stream
            nullptr,                            // endCmdPtr
            0,                                  // numCsrClients
            false,                              // hasStallingCmds
            false,                              // hasRelaxedOrderingDependencies
            false                               // dispatchMonitorFence
        );
    }

    static BatchBuffer createDefaultBatchBuffer(GraphicsAllocation *commandBufferAllocation, LinearStream *stream, size_t usedSize) {
        return createDefaultBatchBuffer(commandBufferAllocation, stream, usedSize, 0);
    }
};
